from captcha.fields import ReCaptchaField

from registration.forms import RegistrationForm

class RegistrationFormCaptcha(RegistrationForm):
    captcha = ReCaptchaField(attrs={'options': {'theme': 'white'}})



from django.conf.urls.defaults import patterns, url

from registration.views import register

urlpatterns = patterns('',
                       url(r'^register/$',
                           register,
                           { 'backend': 'captcha.backends.default.CaptchaDefaultBackend' },
                           name='registration_register'),
                       )
